[CCCL] 瘦身 + 补全: 移除 cudax/python/libcudacxx-tests 冗余文件, 新增 c2h 测试助手 + cmake 构建系统 + 8 个 CUDA thrust examples
变更摘要:
- 删除: cudax/ (783 files, 7.2M) — 实验性组件,竞赛不需要
- 删除: python/ (226 files, 2.0M) — Python 绑定,竞赛不需要
- 删除: libcudacxx/{test,benchmarks,codegen,cmake,share} (4432 files, 31M)
保留: libcudacxx/include/ (1463 headers, cuda::std 编译依赖)
- 新增: c2h/ (27 files) — CUB Catch2 测试辅助头文件,编译 243 个测试必需
- 新增: cmake/ (29 files) — CCCL 原生 CMake 构建系统
- 新增: thrust/examples/cuda/ (7 files) + cpp_integration/ (1 file)
async_reduce, custom_temporary_allocation, explicit_cuda_stream,
global_device_vector, range_view, unwrap_pointer, wrap_pointer, device
结果: cccl_upstream 从 74M→35M (瘦身 53%), 核心内容 100% 保留:
27/27 tuning headers, 78 benchmarks, 243 tests,
60 thrust examples, 18 CUB examples, 全部编译头文件
This commit is contained in:
@@ -1,209 +0,0 @@
|
||||
//===----------------------------------------------------------------------===//
|
||||
//
|
||||
// Part of CUDA Experimental in CUDA C++ Core Libraries,
|
||||
// under the Apache License v2.0 with LLVM Exceptions.
|
||||
// See https://llvm.org/LICENSE.txt for license information.
|
||||
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
|
||||
// SPDX-FileCopyrightText: Copyright (c) 2026 NVIDIA CORPORATION & AFFILIATES.
|
||||
//
|
||||
//===----------------------------------------------------------------------===//
|
||||
|
||||
#include <cuda/devices>
|
||||
#include <cuda/hierarchy>
|
||||
#include <cuda/launch>
|
||||
#include <cuda/std/cstddef>
|
||||
#include <cuda/std/type_traits>
|
||||
#include <cuda/std/utility>
|
||||
#include <cuda/stream>
|
||||
|
||||
#include <cuda/experimental/group.cuh>
|
||||
|
||||
#include "group_testing.cuh"
|
||||
|
||||
namespace
|
||||
{
|
||||
struct AlwaysTruePredFn
|
||||
{
|
||||
template <class MappingResult>
|
||||
__device__ bool operator()(MappingResult mapping_result)
|
||||
{
|
||||
return true;
|
||||
}
|
||||
};
|
||||
|
||||
struct AlwaysFalsePredFn
|
||||
{
|
||||
template <class MappingResult>
|
||||
__device__ bool operator()(MappingResult mapping_result) noexcept
|
||||
{
|
||||
return false;
|
||||
}
|
||||
};
|
||||
|
||||
struct IsEvenPredFn
|
||||
{
|
||||
template <class MappingResult>
|
||||
__device__ bool operator()(MappingResult mapping_result)
|
||||
{
|
||||
return mapping_result.unit_rank() % 2 == 0;
|
||||
}
|
||||
};
|
||||
|
||||
template <class Config>
|
||||
__device__ void test_binary_partition(Config config)
|
||||
{
|
||||
// Always true predicate.
|
||||
{
|
||||
using Pred = AlwaysTruePredFn;
|
||||
using Mapping = cudax::binary_partition<Pred>;
|
||||
|
||||
// Test constructor from pred_fn.
|
||||
{
|
||||
static_assert(cuda::std::is_nothrow_constructible_v<Mapping, Pred>);
|
||||
cudax::binary_partition mapping{Pred{}};
|
||||
}
|
||||
|
||||
// Test map(...).
|
||||
{
|
||||
const cudax::this_warp parent_group{config};
|
||||
const ThreadsInWarpMappingResult prev_mapping_result;
|
||||
|
||||
static_assert(cudax::__group_mapping_result<decltype(cuda::std::declval<const Mapping>().map(
|
||||
cuda::gpu_thread, parent_group, prev_mapping_result))>);
|
||||
static_assert(
|
||||
!noexcept(cuda::std::declval<const Mapping>().map(cuda::gpu_thread, parent_group, prev_mapping_result)));
|
||||
|
||||
const Mapping mapping{Pred{}};
|
||||
auto result = mapping.map(cuda::gpu_thread, parent_group, prev_mapping_result);
|
||||
using Result = decltype(result);
|
||||
|
||||
static_assert(Result::static_group_count() == 2);
|
||||
REQUIRE(result.group_count() == 2);
|
||||
REQUIRE(result.group_rank() == 1);
|
||||
|
||||
static_assert(Result::static_unit_count() == cuda::std::dynamic_extent);
|
||||
REQUIRE(result.unit_count() == cuda::gpu_thread.count(cuda::warp));
|
||||
REQUIRE(result.unit_rank() == cuda::gpu_thread.rank(cuda::warp));
|
||||
|
||||
REQUIRE(result.lane_mask() == cuda::device::lane_mask::all());
|
||||
|
||||
REQUIRE(result.is_valid());
|
||||
static_assert(Result::is_always_exhaustive());
|
||||
static_assert(!Result::is_always_contiguous());
|
||||
}
|
||||
}
|
||||
|
||||
// Always false predicate.
|
||||
{
|
||||
using Pred = AlwaysFalsePredFn;
|
||||
using Mapping = cudax::binary_partition<Pred>;
|
||||
|
||||
// Test constructor from pred_fn.
|
||||
{
|
||||
static_assert(cuda::std::is_nothrow_constructible_v<Mapping, Pred>);
|
||||
cudax::binary_partition mapping{Pred{}};
|
||||
}
|
||||
|
||||
// Test map(...).
|
||||
{
|
||||
const cudax::this_warp parent_group{config};
|
||||
const ThreadsInWarpMappingResult prev_mapping_result;
|
||||
|
||||
static_assert(cudax::__group_mapping_result<decltype(cuda::std::declval<const Mapping>().map(
|
||||
cuda::gpu_thread, parent_group, prev_mapping_result))>);
|
||||
static_assert(
|
||||
noexcept(cuda::std::declval<const Mapping>().map(cuda::gpu_thread, parent_group, prev_mapping_result)));
|
||||
|
||||
const Mapping mapping{Pred{}};
|
||||
auto result = mapping.map(cuda::gpu_thread, parent_group, prev_mapping_result);
|
||||
using Result = decltype(result);
|
||||
|
||||
static_assert(Result::static_group_count() == 2);
|
||||
REQUIRE(result.group_count() == 2);
|
||||
REQUIRE(result.group_rank() == 0);
|
||||
|
||||
static_assert(Result::static_unit_count() == cuda::std::dynamic_extent);
|
||||
REQUIRE(result.unit_count() == cuda::gpu_thread.count(cuda::warp));
|
||||
REQUIRE(result.unit_rank() == cuda::gpu_thread.rank(cuda::warp));
|
||||
|
||||
REQUIRE(result.lane_mask() == cuda::device::lane_mask::all());
|
||||
|
||||
REQUIRE(result.is_valid());
|
||||
static_assert(Result::is_always_exhaustive());
|
||||
static_assert(!Result::is_always_contiguous());
|
||||
}
|
||||
}
|
||||
|
||||
// True for even ranks predicate.
|
||||
{
|
||||
using Pred = IsEvenPredFn;
|
||||
using Mapping = cudax::binary_partition<Pred>;
|
||||
|
||||
// Test constructor from pred_fn.
|
||||
{
|
||||
static_assert(cuda::std::is_nothrow_constructible_v<Mapping, Pred>);
|
||||
cudax::binary_partition mapping{Pred{}};
|
||||
}
|
||||
|
||||
// Test map(...).
|
||||
{
|
||||
const cudax::this_warp parent_group{config};
|
||||
const ThreadsInWarpMappingResult prev_mapping_result;
|
||||
|
||||
static_assert(cudax::__group_mapping_result<decltype(cuda::std::declval<const Mapping>().map(
|
||||
cuda::gpu_thread, parent_group, prev_mapping_result))>);
|
||||
static_assert(
|
||||
!noexcept(cuda::std::declval<const Mapping>().map(cuda::gpu_thread, parent_group, prev_mapping_result)));
|
||||
|
||||
const Mapping mapping{Pred{}};
|
||||
auto result = mapping.map(cuda::gpu_thread, parent_group, prev_mapping_result);
|
||||
using Result = decltype(result);
|
||||
|
||||
static_assert(Result::static_group_count() == 2);
|
||||
REQUIRE(result.group_count() == 2);
|
||||
REQUIRE(result.group_rank() == (cuda::gpu_thread.rank(cuda::warp) % 2 == 0));
|
||||
|
||||
static_assert(Result::static_unit_count() == cuda::std::dynamic_extent);
|
||||
REQUIRE(result.unit_count() == cuda::gpu_thread.count(cuda::warp) / 2);
|
||||
REQUIRE(result.unit_rank() == cuda::gpu_thread.rank(cuda::warp) / 2);
|
||||
|
||||
const auto lane_mask_ref =
|
||||
(cuda::gpu_thread.rank(cuda::warp) % 2 == 0)
|
||||
? cuda::device::lane_mask{0x5555'5555u}
|
||||
: cuda::device::lane_mask(0xaaaa'aaaau);
|
||||
REQUIRE(result.lane_mask() == lane_mask_ref);
|
||||
|
||||
REQUIRE(result.is_valid());
|
||||
static_assert(Result::is_always_exhaustive());
|
||||
static_assert(!Result::is_always_contiguous());
|
||||
}
|
||||
}
|
||||
}
|
||||
|
||||
struct TestKernel
|
||||
{
|
||||
template <class Config>
|
||||
__device__ void operator()(const Config& config)
|
||||
{
|
||||
test_binary_partition(config);
|
||||
}
|
||||
};
|
||||
} // namespace
|
||||
|
||||
C2H_TEST("Binary partition mapping", "[group]")
|
||||
{
|
||||
const auto device = cuda::devices[0];
|
||||
|
||||
const cuda::stream stream{device};
|
||||
|
||||
{
|
||||
const auto config = cuda::make_config(cuda::grid_dims<1>(), cuda::block_dims<8, 4>());
|
||||
cuda::launch(stream, config, TestKernel{});
|
||||
}
|
||||
{
|
||||
const auto config = cuda::make_config(cuda::grid_dims<1>(), cuda::block_dims(dim3{8, 4}));
|
||||
cuda::launch(stream, config, TestKernel{});
|
||||
}
|
||||
|
||||
stream.sync();
|
||||
}
|
||||
Reference in New Issue
Block a user